@@ -10,7 +10,7 @@ def main():
     # Setup logging to stdout, indicate running from cli
     CLI_LOGGING = 'extract_msg_cli'
 
-    args = utils.get_command_args(sys.argv[1:])
+    args = utils.getCommandArgs(sys.argv[1:])
     level = logging.INFO if args.verbose else logging.WARNING
     currentdir = os.getcwdu() # Store this just in case the paths that have been given are relative
     if args.out_path:
@@ -29,17 +29,17 @@ def main():
 
         from extract_msg import validation
 
-        val_results = {x[0]: validation.validate(x[0]) for x in args.msgs}
+        valResults = {x[0]: validation.validate(x[0]) for x in args.msgs}
         filename = 'validation {}.json'.format(int(time.time()))
         print('Validation Results:')
-        pprint.pprint(val_results)
+        pprint.pprint(valResults)
         print('These results have been saved to {}'.format(filename))
         with open(filename, 'w') as fil:
-            fil.write(json.dumps(val_results))
-        utils.get_input('Press enter to exit...')
+            fil.write(json.dumps(valResults))
+        utils.getInput('Press enter to exit...')
     else:
         if not args.dump_stdout:
-            utils.setup_logging(args.config_path, level, args.log, args.file_logging)
+            utils.setupLogging(args.config_path, level, args.log, args.file_logging)
         for x in args.msgs:
             try:
                 with Message(x[0]) as msg:
@@ -48,7 +48,7 @@ def main():
                         print(msg.body)
                     else:
                         os.chdir(out)
-                        msg.save(toJson = args.json, useFileName = args.use_filename, ContentId = args.cid)#, html = args.html, rtf = args.html, args.allowFallback)
+                        msg.save(json = args.json, useMsgFilename = args.use_filename, contentId = args.cid, html = args.html, rtf = args.html, allowFallback = args.allowFallback)
             except Exception as e:
                 print("Error with file '" + x[0] + "': " +
                       traceback.format_exc())
